#!/usr/bin/env ruby
require "fileutils"

# change dir to home folder: https://ruby-doc.org/core-2.7.1/Dir.html
# to find the path to your folder can type: pwd
Dir.chdir("/data")

# Make sure the output folders exist
FileUtils.mkdir_p "./dasy_bam_filt/"
FileUtils.mkdir_p "./dasy_bam_sort2/"

# get an array of files to use
bamfiles = Dir.glob(File.join("**", "dasy_bams", "*.bam"))

# run through the files filtering out unmapped reads
bamfiles.each do |bam_file_path|
  # gsub is a find and replace
  output_filename = bam_file_path.gsub("dasy_bams", "dasy_bam_filt").gsub(".bam", ".bam")
  %x[samtools view -h -F 4 -b #{bam_file_path} > #{output_filename}]
end

# get a new array of files to use
bamfiles = Dir.glob(File.join("**", "dasy_bam_filt", "*.bam"))

# run through the files sorting the reads
bamfiles.each do |bam_file_path|
  # gsub is a find and replace
  output_filename = bam_file_path.gsub("dasy_bam_filt", "dasy_bam_sort2").gsub(".bam", ".bam")
  %x[samtools sort -o #{output_filename} #{bam_file_path}]
end

# get a new array of files to use
bamfiles = Dir.glob(File.join("**", "dasy_bam_sort2", "*.bam"))

# run through the files and index each file
bamfiles.each do |bam_file_path|
  # gsub is a find and replace
  output_filename = bam_file_path.gsub("dasy_bam_sort2", "dasy_bam_sort2").gsub(".bam", ".bai")
  %x[samtools index #{bam_file_path} #{output_filename}]
end
